package
Version:
v0.0.0-...-70c62f1
Opens a new window with list of versions in this module.
Published: Jan 12, 2022
License: AGPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CommandAttributes struct {
Count int `bson:"count,omitempty" json:"count"`
}
type Cooldown struct {
Global int `bson:"global" json:"global"`
User int `bson:"user" json:"user"`
}
type Timer struct {
Enabled bool `bson:"enabled" json:"enabled"`
MinMessages int `bson:"minMessages" json:"minMessages"`
Interval time.Duration `bson:"interval" json:"interval"`
Stream StreamStatus `bson:"stream" json:"stream"`
}
const (
UserRoleGlobal UserRole = 1 << iota
UserRoleSubscriber
UserRoleVIP
UserRoleEditor
UserRoleModerator
UserRoleSuperMod
UserRoleBroadcaster
UserRoleAdmin
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.